@@ -12,27 +12,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
 import os
 import sys
 import importlib
 import logging
 
-
 _MOCK_OPERATOR_DIR = os.path.dirname(__file__)
 
-
 ADD_OPERATOR_PATH = os.path.join(_MOCK_OPERATOR_DIR, "add_operator")
 SUB_OPERATOR_PATH = os.path.join(_MOCK_OPERATOR_DIR, "sub_operator")
 PYTORCH_CNN_OPERATOR_PATH = os.path.join(_MOCK_OPERATOR_DIR, "pytorch_cnn_operator")
 PYTORCH_IMAGE_CLASSIFICATION_OPERATOR_PATH = os.path.join(_MOCK_OPERATOR_DIR, "pytorch_image_classification_operator")
 PYTORCH_OBJECT_DETECTION_OPERATOR_PATH = os.path.join(_MOCK_OPERATOR_DIR, "pytorch_object_detection_operator")
 PYTORCH_TRANSFORMER_OPERATOR_PATH = os.path.join(_MOCK_OPERATOR_DIR, "pytorch_transformer_operator")
-PYTORCH_TRANSFORME_OPERATOR_PATH = os.path.join(_MOCK_OPERATOR_DIR, "pytorch_transform_operator")
+PYTORCH_TRANSFORM_OPERATOR_PATH = os.path.join(_MOCK_OPERATOR_DIR, "pytorch_transform_operator")
 PYTORCH_TRANSFORMER_VEC_OPERATOR_PATH = os.path.join(_MOCK_OPERATOR_DIR, "pytorch_transformer_vec_operator")
 
 
-
 def load_local_operator(op_name: str, op_path: str):
     """
     A simple operator_loader function for UT
@@ -41,11 +37,6 @@ def load_local_operator(op_name: str, op_path: str):
         sys.path.insert(0, op_path)
         return importlib.import_module(op_name)
     except ModuleNotFoundError as e:
-        logging.error(
-            "import model: {op_name} from path: {op_path} failed, error: {err}",
-            op_name=op_name,
-            op_path=op_path,
-            err=str(e)
-        )
+        logging.error("import model: {op_name} from path: {op_path} failed, error: {err}", op_name=op_name, op_path=op_path, err=str(e))
     finally:
         sys.path.pop(0)
